"""
Preprocess a number of snapshots from DFT outputs into data consistent with
the data provided here.
"""

import os

import mala



test_parameters = mala.Parameters()

# These are the LDOS and SNAP values used for this data set.
test_parameters.descriptors.descriptor_type = "SNAP"
test_parameters.descriptors.twojmax = 10
test_parameters.descriptors.rcutfac = 4.67637
test_parameters.data.descriptors_contain_xyz = True
test_parameters.targets.target_type = "LDOS"
test_parameters.targets.ldos_gridoffset_ev = -5
test_parameters.targets.ldos_gridsize = 250
test_parameters.targets.ldos_gridspacing_ev = 0.1

# If possible, the usage of multiple ranks (e.g. 24) is advised.
test_parameters.use_mpi = True

# Data is converted using the MALA DataConverter class.
data_converter = mala.DataConverter(test_parameters)

# Adapt as needed.
calculation_folder = "PATH/TO/YOUR/CALCULATIONS"
N = 20
snapshots = list(range(0, N))
processed_output_folder = "WHERE/YOU/WANT/THE/DATA"

for s in snapshots:
    snapshot_name = "snapshot"+str(s)
    snapshot_folder = os.path.join(calculation_folder, snapshot_name)
    data_converter.add_snapshot_qeout_cube("HOWEVER_YOU_CALL_YOUR_OUTPUTS"+snapshot_name+".out",
                                           snapshot_folder,
                                           "tmp.pp*HOWEVER_YOU_CALL_YOUR_CUBES"+snapshot_name+".cube",
                                           snapshot_folder, output_units="1/Ry")

# Convert all the snapshots and save them in the current directory.
data_converter.convert_snapshots(processed_output_folder,
                                naming_scheme="SOME_NAME_*",
                                starts_at=snapshots[0])
